@@ -17,9 +17,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "debug.h" // always needs to be first include
-
 #include "tabletareaselectioncontroller.h"
+
+#include "logging.h"
 #include "tabletareaselectionview.h"
 #include "calibrationdialog.h"
 
@@ -102,7 +102,7 @@ void TabletAreaSelectionController::setView(TabletAreaSelectionView* view)
     Q_D(TabletAreaSelectionController);
 
     // cleanup signal/slot connections if we already have a view
-    if (d->view != NULL) {
+    if (d->view) {
         disconnect(d->view, SIGNAL(signalCalibrateClicked()),     this, SLOT(onCalibrateClicked()));
         disconnect(d->view, SIGNAL(signalFullTabletSelection()),  this, SLOT(onFullTabletSelected()));
         disconnect(d->view, SIGNAL(signalScreenToggle()),         this, SLOT(onScreenToggle()));
@@ -113,7 +113,7 @@ void TabletAreaSelectionController::setView(TabletAreaSelectionView* view)
     // save view and connect signals
     d->view = view;
 
-    if (view != NULL) {
+    if (view) {
         connect(view, SIGNAL(signalCalibrateClicked()),     this, SLOT(onCalibrateClicked()));
         connect(view, SIGNAL(signalFullTabletSelection()),  this, SLOT(onFullTabletSelected()));
         connect(view, SIGNAL(signalScreenToggle()),         this, SLOT(onScreenToggle()));
@@ -160,7 +160,7 @@ void TabletAreaSelectionController::setupController(const ScreenMap& mappings,
     }
 
 
-    dbgWacom << "Calling setupScreens and setupTablet from setupController.  ScreenGeometries: " << d->screenGeometries;
+    qCDebug(KCM) << "Calling setupScreens and setupTablet from setupController.  ScreenGeometries: " << d->screenGeometries;
     d->view->setupScreens(d->screenGeometries, QSize(200,200));
     d->view->setupTablet(d->tabletGeometryRotated, QSize(400,400));
 
@@ -173,7 +173,7 @@ void TabletAreaSelectionController::onCalibrateClicked()
 {
     Q_D(TabletAreaSelectionController);
 
-    CalibrationDialog calibDialog(d->deviceName);
+    CalibrationDialog calibDialog(d->deviceName, d->currentScreen.toString());
     calibDialog.exec();
 
     setSelection(TabletArea(calibDialog.calibratedArea()));
@@ -230,8 +230,8 @@ void TabletAreaSelectionController::onSetScreenProportions()
     }
 
     // calculate x and y to center the selection
-    int newX = (int)((tabletGeometry.width() - newWidth) / 2.);
-    int newY = (int)((tabletGeometry.height() - newHeight) / 2.);
+    int newX = tabletGeometry.x() + (int)((tabletGeometry.width() - newWidth) / 2.);
+    int newY = tabletGeometry.y() + (int)((tabletGeometry.height() - newHeight) / 2.);
 
     setSelection(TabletArea(QRect(newX, newY, qRound(newWidth), qRound(newHeight))));
 }
