@@ -52,11 +52,6 @@ public:
      */
     const TabletArea getSelection() const;
 
-    /**
-     * @return True if area selection mode is active, false if full tablet is selected.
-     */
-    bool isAreaSelectionMode() const;
-
     /**
      * Selects all of the tablet.
      */
@@ -133,6 +128,15 @@ public slots:
      */
     void onTabletAreaSelected(bool checked);
 
+    /**
+     * @brief onLockProportionsToggled
+     * @param enabled
+     */
+    void onLockProportionsToggled(bool enabled);
+
+    void onSelectionChanged();
+
+    void onFineTuneValuesChanged(QString);
 
 signals:
 
