@@ -18,15 +18,15 @@
  */
 
 #include "tabletdaemon.h"
-#include "debug.h"
 
+#include "logging.h"
 #include "dbustabletservice.h"
 #include "tabletfinder.h"
 #include "tablethandler.h"
 #include "wacomadaptor.h"
 #include "x11eventnotifier.h"
 #include "globalactions.h"
-#include "../version.h"
+#include "../wacomtablet-version.h"
 
 // common includes
 #include "aboutdata.h"
@@ -44,8 +44,9 @@
 
 using namespace Wacom;
 
-K_PLUGIN_FACTORY( WacomTabletFactory, registerPlugin<TabletDaemon>(); )
-K_EXPORT_PLUGIN( WacomTabletFactory( "wacomtabletdaemon" ) )
+K_PLUGIN_FACTORY_WITH_JSON(WacomTabletFactory,
+                           "wacomtablet.json",
+                           registerPlugin<TabletDaemon>();)
 
 namespace Wacom {
 /**
@@ -96,10 +97,8 @@ TabletDaemon::~TabletDaemon()
 
 
 
-void TabletDaemon::onNotify(const QString& eventId, const QString& title, const QString& message)
+void TabletDaemon::onNotify(const QString& eventId, const QString& title, const QString& message) const
 {
-    Q_D( TabletDaemon );
-
     KNotification* notification = new KNotification(eventId);
     notification->setComponentName( QStringLiteral("wacomtablet") );
     notification->setTitle(title);
@@ -118,7 +117,7 @@ void TabletDaemon::onProfileChanged(const QString &tabletId, const QString& prof
     // When closing the KCM module the KAction destructor disables all global shortcuts.
     // Make sure the global shortcuts are restored when a profile changes. This is not
     // optimal but at least it will enable the shortcuts again.
-    dbgWacom << QLatin1String("Restoring global keyboard shortcuts...");
+    qCDebug(KDED) << QLatin1String("Restoring global keyboard shortcuts...");
     setupActions();
 }
 
@@ -131,28 +130,28 @@ void TabletDaemon::setupActions()
     //if someone adds another action also add it to kcmodule/generalwidget.cpp
 
     // This method is called multiple times - make sure the action collection is only created once.
-    if (d->actionCollection.get() == NULL) {
+    if (!d->actionCollection) {
         d->actionCollection = std::shared_ptr<GlobalActions>(new GlobalActions(false, this));
         d->actionCollection->setConfigGlobal(true);
     }
 
-    connect( d->actionCollection.get(), SIGNAL(toggleTouchTriggered()), &(d->tabletHandler), SLOT(onToggleTouch()) );
-    connect( d->actionCollection.get(), SIGNAL(toggleStylusTriggered()), &(d->tabletHandler), SLOT(onTogglePenMode()) );
-    connect( d->actionCollection.get(), SIGNAL(toggleScreenMapTriggered()), &(d->tabletHandler), SLOT(onToggleScreenMapping()) );
-    connect( d->actionCollection.get(), SIGNAL(mapToFullScreenTriggered()), &(d->tabletHandler), SLOT(onMapToFullScreen()) );
-    connect( d->actionCollection.get(), SIGNAL(mapToScreen1Triggered()), &(d->tabletHandler), SLOT(onMapToScreen1()) );
-    connect( d->actionCollection.get(), SIGNAL(mapToScreen2Triggered()), &(d->tabletHandler), SLOT(onMapToScreen2()) );
-    connect( d->actionCollection.get(), SIGNAL(nextProfileTriggered()), &(d->tabletHandler), SLOT(onNextProfile()) );
-    connect( d->actionCollection.get(), SIGNAL(previousProfileTriggered()), &(d->tabletHandler), SLOT(onPreviousProfile()) );
+    connect(d->actionCollection.get(), &GlobalActions::toggleTouchTriggered, &(d->tabletHandler), &TabletHandler::onToggleTouch, Qt::UniqueConnection);
+    connect(d->actionCollection.get(), &GlobalActions::toggleStylusTriggered, &(d->tabletHandler), &TabletHandler::onTogglePenMode, Qt::UniqueConnection);
+    connect(d->actionCollection.get(), &GlobalActions::toggleScreenMapTriggered, &(d->tabletHandler), &TabletHandler::onToggleScreenMapping, Qt::UniqueConnection);
+    connect(d->actionCollection.get(), &GlobalActions::mapToFullScreenTriggered, &(d->tabletHandler), &TabletHandler::onMapToFullScreen, Qt::UniqueConnection);
+    connect(d->actionCollection.get(), &GlobalActions::mapToScreen1Triggered, &(d->tabletHandler), &TabletHandler::onMapToScreen1, Qt::UniqueConnection);
+    connect(d->actionCollection.get(), &GlobalActions::mapToScreen2Triggered, &(d->tabletHandler), &TabletHandler::onMapToScreen2, Qt::UniqueConnection);
+    connect(d->actionCollection.get(), &GlobalActions::nextProfileTriggered, &(d->tabletHandler), &TabletHandler::onNextProfile, Qt::UniqueConnection);
+    connect(d->actionCollection.get(), &GlobalActions::previousProfileTriggered, &(d->tabletHandler), &TabletHandler::onPreviousProfile, Qt::UniqueConnection);
 }
 
 
 
 void TabletDaemon::setupApplication()
 {
-    static AboutData about( QLatin1Literal("wacomtablet"),
-                            i18n( "Graphic Tablet Configuration daemon" ),
-                            QLatin1String(kded_version), i18n( "A Wacom tablet control daemon" ) );
+    static AboutData about(QLatin1Literal("wacomtablet"),
+                           i18n( "Graphic Tablet Configuration daemon"),
+                           QLatin1String(WACOMTABLET_VERSION_STRING), i18n( "A Wacom tablet control daemon" ));
 }
 
 
@@ -163,14 +162,9 @@ void TabletDaemon::setupDBus()
 
     // connect tablet handler events to D-Bus
     // this is done here and not in the D-Bus tablet service to facilitate unit testing
-    connect(&(d->tabletHandler),     SIGNAL (profileChanged(QString, QString)),
-            &(d->dbusTabletService), SLOT   (onProfileChanged(QString, QString)));
-
-    connect(&(d->tabletHandler),     SIGNAL (tabletAdded(TabletInformation)),
-            &(d->dbusTabletService), SLOT   (onTabletAdded(TabletInformation)));
-
-    connect(&(d->tabletHandler),     SIGNAL (tabletRemoved(QString)),
-            &(d->dbusTabletService), SLOT   (onTabletRemoved(QString)));
+    connect(&(d->tabletHandler), &TabletHandler::profileChanged, &(d->dbusTabletService), &DBusTabletService::onProfileChanged);
+    connect(&(d->tabletHandler), &TabletHandler::tabletAdded,    &(d->dbusTabletService), &DBusTabletService::onTabletAdded);
+    connect(&(d->tabletHandler), &TabletHandler::tabletRemoved,  &(d->dbusTabletService), &DBusTabletService::onTabletRemoved);
 }
 
 
