@@ -17,10 +17,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "debug.h" // always needs to be first include
-
 #include "xinputadaptor.h"
 
+#include "logging.h"
 #include "screenspace.h"
 #include "stringutils.h"
 #include "xinputproperty.h"
@@ -47,7 +46,7 @@ class XinputAdaptorPrivate
 
 
 XinputAdaptor::XinputAdaptor(const QString& deviceName)
-    : PropertyAdaptor(NULL), d_ptr(new XinputAdaptorPrivate)
+    : PropertyAdaptor(nullptr), d_ptr(new XinputAdaptorPrivate)
 {
     Q_D( XinputAdaptor );
     d->deviceName = deviceName;
@@ -72,15 +71,15 @@ const QString XinputAdaptor::getProperty(const Property& property) const
 {
     Q_D(const XinputAdaptor);
 
-    const XinputProperty* xinputproperty = XinputProperty::map(property);
+    const XinputProperty *xinputproperty = XinputProperty::map(property);
 
-    if (xinputproperty == NULL) {
-        errWacom << QString::fromLatin1("Can not get unsupported property '%1' from device '%2' using xinput!").arg(property.key()).arg(d->deviceName);
+    if (!xinputproperty) {
+        qCWarning(KDED) << QString::fromLatin1("Can not get unsupported property '%1' from device '%2' using xinput!").arg(property.key()).arg(d->deviceName);
         return QString();
     }
 
     if (!d->device.isOpen()) {
-        errWacom << QString::fromLatin1("Can not get property '%1' from device '%2' because the device is not available!").arg(property.key()).arg(d->deviceName);
+        qCWarning(KDED) << QString::fromLatin1("Can not get property '%1' from device '%2' because the device is not available!").arg(property.key()).arg(d->deviceName);
         return QString();
     }
 
@@ -92,17 +91,17 @@ bool XinputAdaptor::setProperty(const Property& property, const QString& value)
 {
     Q_D(const XinputAdaptor);
 
-    dbgWacom << QString::fromLatin1("Setting property '%1' to '%2'.").arg(property.key()).arg(value);
+    qCDebug(KDED) << QString::fromLatin1("Setting property '%1' to '%2'.").arg(property.key()).arg(value);
 
-    const XinputProperty* xinputproperty = XinputProperty::map(property);
+    const XinputProperty *xinputproperty = XinputProperty::map(property);
 
-    if (xinputproperty == NULL) {
-        errWacom << QString::fromLatin1("Can not set unsupported property '%1' to '%2' on device '%3' using xinput!").arg(property.key()).arg(value).arg(d->deviceName);
+    if (!xinputproperty) {
+        qCWarning(KDED) << QString::fromLatin1("Can not set unsupported property '%1' to '%2' on device '%3' using xinput!").arg(property.key()).arg(value).arg(d->deviceName);
         return false;
     }
 
     if (!d->device.isOpen()) {
-        errWacom << QString::fromLatin1("Can not set property '%1' to '%2' on device '%3' because the device is not available!").arg(property.key()).arg(value).arg(d->deviceName);
+        qCWarning(KDED) << QString::fromLatin1("Can not set property '%1' to '%2' on device '%3' because the device is not available!").arg(property.key()).arg(value).arg(d->deviceName);
         return false;
     }
 
@@ -112,7 +111,7 @@ bool XinputAdaptor::setProperty(const Property& property, const QString& value)
 
 bool XinputAdaptor::supportsProperty(const Property& property) const
 {
-    return (XinputProperty::map(property) != NULL);
+    return (XinputProperty::map(property) != nullptr);
 }
 
 
@@ -137,7 +136,7 @@ const QString XinputAdaptor::getProperty(const XinputProperty& property) const
         return (X11Wacom::isScrollDirectionInverted(d->deviceName) ? QLatin1String("on") : QLatin1String("off"));
 
     } else {
-        errWacom << QString::fromLatin1("Getting Xinput property '%1' is not yet implemented!").arg(property.key());
+        qCWarning(KDED) << QString::fromLatin1("Getting Xinput property '%1' is not yet implemented!").arg(property.key());
     }
 
     return QString();
@@ -152,7 +151,7 @@ const QString XinputAdaptor::getFloatProperty(const XinputProperty& property, lo
     QList<float> values;
 
     if (!d->device.getFloatProperty(property.key(), values, nelements)) {
-        errWacom << QString::fromLatin1("Failed to get Xinput property '%1' from device '%2'!").arg(property.key()).arg(d->deviceName);
+        qCWarning(KDED) << QString::fromLatin1("Failed to get Xinput property '%1' from device '%2'!").arg(property.key()).arg(d->deviceName);
         return QString();
     }
 
@@ -168,7 +167,7 @@ const QString XinputAdaptor::getLongProperty(const XinputProperty& property, lon
     QList<long> values;
 
     if (!d->device.getLongProperty(property.key(), values, nelements)) {
-        errWacom << QString::fromLatin1("Failed to get Xinput property '%1' from device '%2'!").arg(property.key()).arg(d->deviceName);
+        qCWarning(KDED) << QString::fromLatin1("Failed to get Xinput property '%1' from device '%2'!").arg(property.key()).arg(d->deviceName);
         return QString();
     }
 
@@ -188,7 +187,7 @@ bool XinputAdaptor::mapTabletToScreen(const QString& screenArea) const
     // | 0  h  offsetY |
     // | 0  0     1    |
 
-    dbgWacom << "Mapping to area: " << screenArea;
+    qCDebug(KDED) << "Mapping to area: " << screenArea;
 
     if (screenArea.isEmpty()) {
         return false; // nothing to do
@@ -201,7 +200,7 @@ bool XinputAdaptor::mapTabletToScreen(const QString& screenArea) const
 
     if (screenSpace.isDesktop()) {
         // full screen area selected
-        dbgWacom << "Full screen area selected: " << fullScreenGeometry;
+        qCDebug(KDED) << "Full screen area selected: " << fullScreenGeometry;
         screenAreaGeometry = fullScreenGeometry;
 
     } else if (screenSpace.isMonitor()) {
@@ -210,21 +209,21 @@ bool XinputAdaptor::mapTabletToScreen(const QString& screenArea) const
         QMap<QString, QRect> screenList = X11Info::getScreenGeometries();
 
         if (!screenList.contains(output)) {
-            dbgWacom << "Selected monitor no longer connected - using full screen: " << fullScreenGeometry;
+            qCDebug(KDED) << "Selected monitor no longer connected - using full screen: " << fullScreenGeometry;
             screenAreaGeometry = fullScreenGeometry;
         } else {
-            dbgWacom << "Use monitor geometry for screen " << output << ": " << screenList.value(output);
+            qCDebug(KDED) << "Use monitor geometry for screen " << output << ": " << screenList.value(output);
             screenAreaGeometry = screenList.value(output);
         }
 
     } else {
         // geometry selected
-        dbgWacom << "Geometry selected: " << StringUtils::toQRect(screenArea, true);
+        qCDebug(KDED) << "Geometry selected: " << StringUtils::toQRect(screenArea, true);
         screenAreaGeometry = StringUtils::toQRect(screenArea, true);
 
         if (screenAreaGeometry.isEmpty()) {
             // the input is invalid - use full screen
-            errWacom << "mapTabletToScreen :: can't parse ScreenSpace entry '" << screenArea << "' => device:" << d->deviceName;
+            qCWarning(KDED) << "mapTabletToScreen :: can't parse ScreenSpace entry '" << screenArea << "' => device:" << d->deviceName;
             screenAreaGeometry = fullScreenGeometry;
         }
     }
@@ -241,10 +240,10 @@ bool XinputAdaptor::mapTabletToScreen(const QString& screenArea) const
     qreal offsetX = static_cast<qreal>(screenX) / fullScreenGeometry.width();
     qreal offsetY = static_cast<qreal>(screenY) / fullScreenGeometry.height();
 
-    dbgWacom << "Apply Coordinate Transformation Matrix";
-    dbgWacom << w << "0" << offsetX;
-    dbgWacom << "0" << h << offsetY;
-    dbgWacom << "0" << "0" << "1";
+    qCDebug(KDED) << "Apply Coordinate Transformation Matrix";
+    qCDebug(KDED) << w << "0" << offsetX;
+    qCDebug(KDED) << "0" << h << offsetY;
+    qCDebug(KDED) << "0" << "0" << "1";
 
     return X11Wacom::setCoordinateTransformationMatrix(d->deviceName, offsetX, offsetY, w, h);
 }
@@ -292,7 +291,7 @@ bool XinputAdaptor::setProperty (const XinputProperty& property, const QString&
         return mapTabletToScreen (value);
 
     } else {
-        errWacom << QString::fromLatin1("Setting Xinput property '%1' is not yet implemented!").arg(property.key());
+        qCWarning(KDED) << QString::fromLatin1("Setting Xinput property '%1' is not yet implemented!").arg(property.key());
     }
 
     return false;
